@@ -1,7 +1,34 @@
 import json
-import os
+from dataclasses import dataclass
 
-from uetools.conf import Command, load_conf
+from uetools.core.command import Command, newparser
+from uetools.core.conf import find_project
+
+
+@dataclass
+class Arguments:
+    """Disable a plugin
+
+    Attributes
+    ----------
+    name: str
+        Name of the project to modify
+
+    plugin: str
+        Name of the plugin to disable
+
+    Examples
+    --------
+
+    .. code-block:: console
+
+       # Disable the plugin
+       uecli disable RTSGame RTSGamePlugin
+
+    """
+
+    name: str
+    plugin: str
 
 
 class Disable(Command):
@@ -11,18 +38,14 @@ class Disable(Command):
 
     @staticmethod
     def arguments(subparsers):
-        disable = subparsers.add_parser(
-            Disable.name, help="Install uetools in a unreal project"
-        )
-        disable.add_argument("name", type=str, help="project's name")
-        disable.add_argument("plugin", type=str, help="Plugin's name")
+        parser = newparser(subparsers, Disable)
+        parser.add_argument("name", type=str, help="project's name")
+        parser.add_argument("plugin", type=str, help="Plugin's name")
 
     @staticmethod
     def execute(args):
         name = args.name
-        projects_folder = load_conf().get("project_path")
-        project_folder = os.path.join(projects_folder, name)
-        uproject = os.path.join(project_folder, f"{name}.uproject")
+        uproject = find_project(args.name)
 
         with open(uproject, "r", encoding="utf-8") as project_file:
             project_conf = json.load(project_file)
@@ -38,7 +61,6 @@ class Disable(Command):
 
         if args.plugin in plugin_dict:
             plugin_dict[args.plugin]["Enabled"] = False
-
         else:
             plugins.append(dict(Name=args.plugin, Enabled=False))
 
@@ -46,4 +68,4 @@ class Disable(Command):
             json.dump(project_conf, project_file)
 
 
-COMMAND = Disable
+COMMANDS = Disable
