@@ -1,7 +1,24 @@
 import os
-import subprocess
+from dataclasses import dataclass, field
+from typing import List
 
-from uetools.conf import Command, get_build_platforms, load_conf, uat
+from uetools.core.command import Command, newparser
+from uetools.core.conf import find_project, get_build_platforms, uat
+from uetools.core.run import run
+
+
+# fmt: off
+@dataclass
+class Arguments:
+    """Builds and cook a plugin"""
+
+    project         : str # Name of the project
+    plugin          : str # Path to the plugin (relative to project folder)
+    platforms       : List[str] = field(default_factory=list)
+    output          : str       = None  # Packaged plugin destination
+    strict_includes : bool      = False #
+    no_host_platform: bool      = False #
+# fmt: on
 
 
 class PackagePlugin(Command):
@@ -11,14 +28,12 @@ class PackagePlugin(Command):
 
     @staticmethod
     def arguments(subparsers):
-        cook = subparsers.add_parser(
-            PackagePlugin.name, help="Package an UnrealEngine Plugin"
-        )
-        cook.add_argument("project", type=str, help="Project name")
+        parser = newparser(subparsers, PackagePlugin)
+        parser.add_argument("project", type=str, help="Project name")
 
-        cook.add_argument("plugin", type=str, help="Path to uplugin file")
+        parser.add_argument("plugin", type=str, help="Path to uplugin file (relative)")
 
-        cook.add_argument(
+        parser.add_argument(
             "--platforms",
             type=str,
             nargs="+",
@@ -26,17 +41,17 @@ class PackagePlugin(Command):
             help="list of platforms to build for",
         )
 
-        cook.add_argument(
+        parser.add_argument(
             "--output", type=str, help="path to build the packaged plugin"
         )
 
-        cook.add_argument(
+        parser.add_argument(
             "--strict-includes",
             action="store_true",
             help="Disables precompiled headers & unity build. (Forces Headers to include all their dependencies)",
         )
 
-        cook.add_argument(
+        parser.add_argument(
             "--no-host-platform",
             action="store_true",
             help="Does not compile the editor platform on the host",
@@ -47,10 +62,15 @@ class PackagePlugin(Command):
         project = args.project
         plugin = args.plugin
 
-        projects_folder = load_conf().get("project_path")
-        project_folder = os.path.join(projects_folder, project)
+        project = find_project(args.project)
+        folder = os.path.dirname(project)
 
-        plugin_path = os.path.join(project_folder, plugin)
+        print()
+        print(args.project, project)
+        print(folder)
+        print()
+
+        plugin_path = os.path.join(folder, plugin)
 
         platforms = "+".join(args.platforms)
 
@@ -63,19 +83,18 @@ class PackagePlugin(Command):
             # what does this do ?
             "-Rocket",
         ]
+
         if args.strict_includes:
             cmdargs.append("-StrictIncludes")
 
         if args.no_host_platform:
             cmdargs.append("-NoHostPlatform ")
 
-        subprocess.run(
+        print(" ".join(cmdargs))
+        run(
             cmdargs,
-            stdin=subprocess.PIPE,
-            stderr=subprocess.PIPE,
-            shell=True,
             check=True,
         )
 
 
-COMMAND = PackagePlugin
+COMMANDS = PackagePlugin
